==> ui-react-1.1.461.tgz: package/esm/Medias/Medias.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
const _excluded = ["size", "values", "imageGallery", "show", "noName", "IconDocument", "NameProps", "WrapperProps", "ImageProps", "AudioProps", "VideoProps", "OtherProps", "ItemsProps", "ImageItemsProps", "AudioItemsProps", "VideoItemsProps", "OtherItemsProps", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import TypeElement from '../Type';
import InteractionElement from '../Interaction';
import LineElement from '../Line/Line';
import AudioPlayerElement from '../AudioPlayer';
import VideoPlayerElement from '../VideoPlayer';
import PortalElement from '../Portal';
import ImageGalleryElement from '../ImageGallery';
import IconElement from '../Icon';
import { staticClassName } from '../utils';
const IconMaterialDraft = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "Draft",
    short_name: "Draft",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M6 22q-.825 0-1.412-.587Q4 20.825 4 20V4q0-.825.588-1.413Q5.175 2 6 2h7.175q.4 0 .763.15.362.15.637.425l4.85 4.85q.275.275.425.637.15.363.15.763V20q0 .825-.587 1.413Q18.825 22 18 22Zm7-14V4H6v16h12V9h-4q-.425 0-.712-.288Q13 8.425 13 8ZM6 4v5-5 16V4Z"
  }));
});
const useStyle = styleMethod(theme => ({
  root: {},
  items: {
    padding: theme.methods.space.value(0.5, 'px'),
    overflow: 'auto hidden'
  },
  item: {},
  wrapper: {
    position: 'relative',
    flex: '0 0 auto'
  },
  wrapper_image: {
    transition: theme.methods.transitions.make('transform'),
    '&:active': {
      transform: 'scale(0.94)'
    }
  },
  wrapper_other: {
    transition: theme.methods.transitions.make('transform'),
    '&:active': {
      transform: 'scale(0.94)'
    }
  },
  name: {
    wordBreak: 'break-word'
  },
  image: {
    position: 'relative',
    backgroundSize: 'cover',
    backgroundPosition: 'center',
    backgroundRepeat: 'no-repeat',
    aspectRatio: '16 / 9'
  },
  imageWrapper_size_small: {
    width: '174px'
  },
  imageWrapper_size_regular: {
    width: '214px'
  },
  imageWrapper_size_large: {
    width: '254px'
  },
  image_size_small: {
    borderRadius: theme.methods.shape.radius.value(1)
  },
  image_size_regular: {
    borderRadius: theme.methods.shape.radius.value(2)
  },
  image_size_large: {
    borderRadius: theme.methods.shape.radius.value(3)
  },
  audioWrapper_size_small: {
    width: '324px'
  },
  audioWrapper_size_regular: {
    width: '340px'
  },
  audioWrapper_size_large: {
    width: '440px'
  },
  videoWrapper_size_small: {
    width: '324px'
  },
  videoWrapper_size_regular: {
    width: '340px'
  },
  videoWrapper_size_large: {
    width: '440px'
  },
  other: {
    position: 'relative',
    aspectRatio: '3 / 4',
    cursor: 'pointer',
    userSelect: 'none',
    background: theme.palette.background.secondary.tertiary,
    boxShadow: theme.shadows.values.default[1]
  },
  otherWrapper_size_small: {
    width: '74px'
  },
  otherWrapper_size_regular: {
    width: '94px'
  },
  otherWrapper_size_large: {
    width: '114px'
  },
  other_size_small: {
    borderRadius: theme.methods.shape.radius.value(1)
  },
  other_size_regular: {
    borderRadius: theme.methods.shape.radius.value(2)
  },
  other_size_large: {
    borderRadius: theme.methods.shape.radius.value(3)
  }
}), {
  name: 'amaui-Medias'
});
const Medias = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiMedias?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const Interaction = React.useMemo(() => theme?.elements?.Interaction || InteractionElement, [theme]);
  const AudioPlayer = React.useMemo(() => theme?.elements?.AudioPlayer || AudioPlayerElement, [theme]);
  const VideoPlayer = React.useMemo(() => theme?.elements?.VideoPlayer || VideoPlayerElement, [theme]);
  const Portal = React.useMemo(() => theme?.elements?.Portal || PortalElement, [theme]);
  const ImageGallery = React.useMemo(() => theme?.elements?.ImageGallery || ImageGalleryElement, [theme]);
  const {
      size = 'regular',
      values: values_ = [],
      imageGallery = true,
      show = ['image', 'video', 'audio', 'other'],
      noName,
      IconDocument = IconMaterialDraft,
      NameProps,
      WrapperProps,
      ImageProps,
      AudioProps,
      VideoProps,
      OtherProps,
      ItemsProps,
      ImageItemsProps,
      AudioItemsProps,
      VideoItemsProps,
      OtherItemsProps,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [open, setOpen] = React.useState();
  const refs = {
    root: React.useRef()
  };
  const values = is('array', values_) ? values_ : [values_];
  const onOpen = React.useCallback(index => {
    setOpen({
      index
    });
  }, []);
  const onClose = React.useCallback(() => {
    setOpen(null);
  }, []);
  const onOpenMedia = React.useCallback(media => {
    window.open(media.url || media.src || media.urlSmall || media.srcSmall, 'blank_');
  }, []);
  const items = React.useMemo(() => {
    const items_ = {
      image: [],
      audio: [],
      video: [],
      other: []
    };
    values.filter(Boolean).forEach(item => {
      const media = item.value;
      if (media) {
        if (media.mime?.startsWith('image')) items_.image.push(item);else if (media.mime?.startsWith('audio')) items_.audio.push(item);else if (media.mime?.startsWith('video')) items_.video.push(item);else items_.other.push(item);
      }
    });
    return items_;
  }, [values]);
  const getItem = (version, item, index) => {
    const media = item.value;
    const name = (item?.props?.name || !noName) && /*#__PURE__*/React.createElement(Type, _extends({
      version: size === 'large' ? 'l2' : size === 'regular' ? 'l3' : 'l3'
    }, NameProps, {
      className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-name'], NameProps?.className, classes.name])
    }), media?.name || 'No name');
    if (version === 'image') {
      return /*#__PURE__*/React.createElement(Line, _extends({
        key: index,
        gap: 1
      }, WrapperProps, {
        onClick: () => imageGallery && onOpen(index),
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-wrapper', 'amaui-Medias-wrapper-image'], WrapperProps?.className, classes.wrapper, classes.wrapper_image, classes[`imageWrapper_size_${size}`]])
      }), /*#__PURE__*/React.createElement(Line, _extends({
        key: index
      }, ImageProps, item?.props, {
        fullWidth: true,
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-item', 'amaui-Medias-item-image'], ImageProps?.className, item?.props?.className, classes.item, classes.image, classes[`image_size_${size}`]]),
        style: _objectSpread({
          backgroundImage: `url(${media.urlSmall || media.srcSmall || media.url || media.src})`
        }, item?.props?.style)
      }), /*#__PURE__*/React.createElement(Interaction, null)), name);
    }
    if (version === 'audio') {
      return /*#__PURE__*/React.createElement(Line, _extends({
        key: index,
        gap: 1
      }, WrapperProps, {
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-wrapper', 'amaui-Medias-wrapper-audio'], WrapperProps?.className, classes.wrapper, classes[`audioWrapper_size_${size}`]])
      }), /*#__PURE__*/React.createElement(AudioPlayer, _extends({
        key: index,
        tonal: true,
        color: "primary",
        src: media.url || media.src || media.urlSmall || media.srcSmall
      }, media, AudioProps, item?.props, {
        fullWidth: true,
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-item', 'amaui-Medias-item-audio'], VideoProps?.className, item?.props?.className, classes.item, classes.audio])
      })), name);
    }
    if (version === 'video') {
      return /*#__PURE__*/React.createElement(Line, _extends({
        key: index,
        gap: 1
      }, WrapperProps, {
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-wrapper', 'amaui-Medias-wrapper-video'], WrapperProps?.className, classes.wrapper, classes[`videoWrapper_size_${size}`]])
      }), /*#__PURE__*/React.createElement(VideoPlayer, _extends({
        key: index,
        tonal: true,
        color: "primary",
        src: media.url || media.src || media.urlSmall || media.srcSmall
      }, media, VideoProps, item?.props, {
        fullWidth: true,
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-item', 'amaui-Medias-item-video'], VideoProps?.className, item?.props?.className, classes.item, classes.video])
      })), name);
    }
    if (version === 'other') {
      return /*#__PURE__*/React.createElement(Line, _extends({
        key: index,
        gap: 1
      }, WrapperProps, {
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-wrapper', 'amaui-Medias-wrapper-other'], WrapperProps?.className, classes.wrapper, classes[`otherWrapper_size_${size}`]])
      }), /*#__PURE__*/React.createElement(Line, _extends({
        key: index
      }, OtherProps, item?.props, {
        align: "center",
        justify: "center",
        onClick: () => onOpenMedia(media),
        fullWidth: true,
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-item', 'amaui-Medias-item-other'], OtherProps?.className, item?.props?.className, classes.item, classes.other, classes[`other_size_${size}`]])
      }), /*#__PURE__*/React.createElement(Interaction, null), /*#__PURE__*/React.createElement(IconDocument, {
        size: size === 'large' ? 44 : size === 'regular' ? 34 : 24
      })), name);
    }
    return null;
  };
  return /*#__PURE__*/React.createElement(Line, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    gap: size === 'large' ? 3 : size === 'regular' ? 2 : 1.5,
    fullWidth: true,
    className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-root', `amaui-Medias-size-${size}`], className, classes.root])
  }, other), show.filter(item => !!items[item]?.length).map((item, index) => /*#__PURE__*/React.createElement(Line, _extends({
    key: index,
    gap: size === 'large' ? 2 : size === 'regular' ? 1.5 : 1,
    direction: "row",
    align: "flex-start",
    justify: "flex-start",
    fullWidth: true
  }, ItemsProps, item === 'image' && ImageItemsProps, item === 'audio' && AudioItemsProps, item === 'video' && VideoItemsProps, item === 'other' && OtherItemsProps, {
    className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-items', `amaui-Medias-items-${item}`], ItemsProps?.className, item === 'image' && ImageItemsProps?.className, item === 'audio' && AudioItemsProps?.className, item === 'video' && VideoItemsProps?.className, item === 'other' && OtherItemsProps?.className, classes.items])
  }), items[item].map((itemMedia, indexItemMedia) => getItem(item, itemMedia, indexItemMedia)))), refs.root.current && imageGallery && !!items.image?.length && /*#__PURE__*/React.createElement(Portal, {
    element: refs.root.current?.ownerDocument?.body
  }, /*#__PURE__*/React.createElement(ImageGallery, {
    open: !!open,
    onClose: onClose,
    value: open?.index,
    items: items.image.map(item => _objectSpread(_objectSpread({}, item.value), {}, {
      url: item.value.url || item.value.src || item.value.urlSmall || item.value.srcSmall,
      urlSmall: item.value.urlSmall || item.value.srcSmall || item.value.url || item.value.src
    }))
  })));
});
Medias.displayName = 'amaui-Medias';
export default Medias;

==> ui-react-1.1.526.tgz: package/esm/Medias/Medias.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
const _excluded = ["size", "values", "imageGallery", "show", "noName", "IconDocument", "NameProps", "WrapperProps", "ImageProps", "AudioProps", "VideoProps", "OtherProps", "ItemsProps", "ImageItemsProps", "AudioItemsProps", "VideoItemsProps", "OtherItemsProps", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import TypeElement from '../Type';
import InteractionElement from '../Interaction';
import LineElement from '../Line/Line';
import AudioPlayerElement from '../AudioPlayer';
import VideoPlayerElement from '../VideoPlayer';
import PortalElement from '../Portal';
import ImageGalleryElement from '../ImageGallery';
import IconElement from '../Icon';
import { staticClassName } from '../utils';
const IconMaterialDraft = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "Draft",
    short_name: "Draft",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M6 22q-.825 0-1.412-.587Q4 20.825 4 20V4q0-.825.588-1.413Q5.175 2 6 2h7.175q.4 0 .763.15.362.15.637.425l4.85 4.85q.275.275.425.637.15.363.15.763V20q0 .825-.587 1.413Q18.825 22 18 22Zm7-14V4H6v16h12V9h-4q-.425 0-.712-.288Q13 8.425 13 8ZM6 4v5-5 16V4Z"
  }));
});
const useStyle = styleMethod(theme => ({
  root: {},
  items: {
    padding: theme.methods.space.value(0.5, 'px'),
    overflow: 'auto hidden'
  },
  item: {},
  wrapper: {
    position: 'relative',
    flex: '0 0 auto'
  },
  wrapper_image: {
    transition: theme.methods.transitions.make('transform'),
    '&:active': {
      transform: 'scale(0.94)'
    }
  },
  wrapper_other: {
    transition: theme.methods.transitions.make('transform'),
    '&:active': {
      transform: 'scale(0.94)'
    }
  },
  name: {
    wordBreak: 'break-word'
  },
  image: {
    position: 'relative',
    backgroundSize: 'cover',
    backgroundPosition: 'center',
    backgroundRepeat: 'no-repeat',
    aspectRatio: '16 / 9'
  },
  imageWrapper_size_small: {
    width: '174px'
  },
  imageWrapper_size_regular: {
    width: '214px'
  },
  imageWrapper_size_large: {
    width: '254px'
  },
  image_size_small: {
    borderRadius: theme.methods.shape.radius.value(1)
  },
  image_size_regular: {
    borderRadius: theme.methods.shape.radius.value(2)
  },
  image_size_large: {
    borderRadius: theme.methods.shape.radius.value(3)
  },
  audioWrapper_size_small: {
    width: '324px'
  },
  audioWrapper_size_regular: {
    width: '340px'
  },
  audioWrapper_size_large: {
    width: '440px'
  },
  videoWrapper_size_small: {
    width: '324px'
  },
  videoWrapper_size_regular: {
    width: '340px'
  },
  videoWrapper_size_large: {
    width: '440px'
  },
  other: {
    position: 'relative',
    aspectRatio: '3 / 4',
    cursor: 'pointer',
    userSelect: 'none',
    background: theme.palette.background.secondary.tertiary,
    boxShadow: theme.shadows.values.default[1]
  },
  otherWrapper_size_small: {
    width: '74px'
  },
  otherWrapper_size_regular: {
    width: '94px'
  },
  otherWrapper_size_large: {
    width: '114px'
  },
  other_size_small: {
    borderRadius: theme.methods.shape.radius.value(1)
  },
  other_size_regular: {
    borderRadius: theme.methods.shape.radius.value(2)
  },
  other_size_large: {
    borderRadius: theme.methods.shape.radius.value(3)
  }
}), {
  name: 'amaui-Medias'
});
const Medias = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiMedias?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const Interaction = React.useMemo(() => theme?.elements?.Interaction || InteractionElement, [theme]);
  const AudioPlayer = React.useMemo(() => theme?.elements?.AudioPlayer || AudioPlayerElement, [theme]);
  const VideoPlayer = React.useMemo(() => theme?.elements?.VideoPlayer || VideoPlayerElement, [theme]);
  const Portal = React.useMemo(() => theme?.elements?.Portal || PortalElement, [theme]);
  const ImageGallery = React.useMemo(() => theme?.elements?.ImageGallery || ImageGalleryElement, [theme]);
  const {
      size = 'regular',
      values: values_ = [],
      imageGallery = true,
      show = ['image', 'video', 'audio', 'other'],
      noName,
      IconDocument = IconMaterialDraft,
      NameProps,
      WrapperProps,
      ImageProps,
      AudioProps,
      VideoProps,
      OtherProps,
      ItemsProps,
      ImageItemsProps,
      AudioItemsProps,
      VideoItemsProps,
      OtherItemsProps,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [open, setOpen] = React.useState();
  const refs = {
    root: React.useRef()
  };
  const values = is('array', values_) ? values_ : [values_];
  const onOpen = React.useCallback(index => {
    setOpen({
      index
    });
  }, []);
  const onClose = React.useCallback(() => {
    setOpen(null);
  }, []);
  const onOpenMedia = React.useCallback(media => {
    window.open(media.url || media.src || media.urlSmall || media.srcSmall, 'blank_');
  }, []);
  const items = React.useMemo(() => {
    const items_ = {
      image: [],
      audio: [],
      video: [],
      other: []
    };
    values.filter(Boolean).forEach(item => {
      const media = item.value;
      if (media) {
        if (media.mime?.startsWith('image')) items_.image.push(item);else if (media.mime?.startsWith('audio')) items_.audio.push(item);else if (media.mime?.startsWith('video')) items_.video.push(item);else items_.other.push(item);
      }
    });
    return items_;
  }, [values]);
  const getItem = (version, item, index) => {
    const media = item.value;
    const name = (item?.props?.name || !noName) && /*#__PURE__*/React.createElement(Type, _extends({
      version: size === 'large' ? 'l2' : size === 'regular' ? 'l3' : 'l3'
    }, NameProps, {
      className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-name'], NameProps?.className, classes.name])
    }), media?.name || 'No name');
    if (version === 'image') {
      return /*#__PURE__*/React.createElement(Line, _extends({
        key: index,
        gap: 1
      }, WrapperProps, {
        onClick: () => imageGallery && onOpen(index),
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-wrapper', 'amaui-Medias-wrapper-image'], WrapperProps?.className, classes.wrapper, classes.wrapper_image, classes[`imageWrapper_size_${size}`]])
      }), /*#__PURE__*/React.createElement(Line, _extends({
        key: index
      }, ImageProps, item?.props, {
        fullWidth: true,
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-item', 'amaui-Medias-item-image'], ImageProps?.className, item?.props?.className, classes.item, classes.image, classes[`image_size_${size}`]]),
        style: _objectSpread({
          backgroundImage: `url(${media.urlSmall || media.srcSmall || media.url || media.src})`
        }, item?.props?.style)
      }), /*#__PURE__*/React.createElement(Interaction, null)), name);
    }
    if (version === 'audio') {
      return /*#__PURE__*/React.createElement(Line, _extends({
        key: index,
        gap: 1
      }, WrapperProps, {
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-wrapper', 'amaui-Medias-wrapper-audio'], WrapperProps?.className, classes.wrapper, classes[`audioWrapper_size_${size}`]])
      }), /*#__PURE__*/React.createElement(AudioPlayer, _extends({
        key: index,
        tonal: true,
        color: "primary",
        src: media.url || media.src || media.urlSmall || media.srcSmall,
        size: size
      }, media, AudioProps, item?.props, {
        fullWidth: true,
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-item', 'amaui-Medias-item-audio'], VideoProps?.className, item?.props?.className, classes.item, classes.audio])
      })), name);
    }
    if (version === 'video') {
      return /*#__PURE__*/React.createElement(Line, _extends({
        key: index,
        gap: 1
      }, WrapperProps, {
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-wrapper', 'amaui-Medias-wrapper-video'], WrapperProps?.className, classes.wrapper, classes[`videoWrapper_size_${size}`]])
      }), /*#__PURE__*/React.createElement(VideoPlayer, _extends({
        key: index,
        tonal: true,
        color: "primary",
        src: media.url || media.src || media.urlSmall || media.srcSmall,
        size: size
      }, media, VideoProps, item?.props, {
        fullWidth: true,
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-item', 'amaui-Medias-item-video'], VideoProps?.className, item?.props?.className, classes.item, classes.video])
      })), name);
    }
    if (version === 'other') {
      return /*#__PURE__*/React.createElement(Line, _extends({
        key: index,
        gap: 1
      }, WrapperProps, {
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-wrapper', 'amaui-Medias-wrapper-other'], WrapperProps?.className, classes.wrapper, classes[`otherWrapper_size_${size}`]])
      }), /*#__PURE__*/React.createElement(Line, _extends({
        key: index
      }, OtherProps, item?.props, {
        align: "center",
        justify: "center",
        onClick: () => onOpenMedia(media),
        fullWidth: true,
        className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-item', 'amaui-Medias-item-other'], OtherProps?.className, item?.props?.className, classes.item, classes.other, classes[`other_size_${size}`]])
      }), /*#__PURE__*/React.createElement(Interaction, null), /*#__PURE__*/React.createElement(IconDocument, {
        size: size === 'large' ? 44 : size === 'regular' ? 34 : 24
      })), name);
    }
    return null;
  };
  return /*#__PURE__*/React.createElement(Line, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    gap: size === 'large' ? 3 : size === 'regular' ? 2 : 1.5,
    fullWidth: true,
    className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-root', `amaui-Medias-size-${size}`], className, classes.root])
  }, other), show.filter(item => !!items[item]?.length).map((item, index) => /*#__PURE__*/React.createElement(Line, _extends({
    key: index,
    gap: size === 'large' ? 2 : size === 'regular' ? 1.5 : 1,
    direction: "row",
    align: "flex-start",
    justify: "flex-start",
    fullWidth: true
  }, ItemsProps, item === 'image' && ImageItemsProps, item === 'audio' && AudioItemsProps, item === 'video' && VideoItemsProps, item === 'other' && OtherItemsProps, {
    className: classNames([staticClassName('Medias', theme) && ['amaui-Medias-items', `amaui-Medias-items-${item}`], ItemsProps?.className, item === 'image' && ImageItemsProps?.className, item === 'audio' && AudioItemsProps?.className, item === 'video' && VideoItemsProps?.className, item === 'other' && OtherItemsProps?.className, classes.items])
  }), items[item].map((itemMedia, indexItemMedia) => getItem(item, itemMedia, indexItemMedia)))), refs.root.current && imageGallery && !!items.image?.length && /*#__PURE__*/React.createElement(Portal, {
    element: refs.root.current?.ownerDocument?.body
  }, /*#__PURE__*/React.createElement(ImageGallery, {
    open: !!open,
    onClose: onClose,
    value: open?.index,
    items: items.image.map(item => _objectSpread(_objectSpread({}, item.value), {}, {
      url: item.value.url || item.value.src || item.value.urlSmall || item.value.srcSmall,
      urlSmall: item.value.urlSmall || item.value.srcSmall || item.value.url || item.value.src
    }))
  })));
});
Medias.displayName = 'amaui-Medias';
export default Medias;
